@@ -28,15 +28,16 @@ class DockerComposeLibrary:
 
     ROBOT_LIBRARY_SCOPE = 'TEST SUITE'
 
+    _docker_compose_cmd: [str]
     _docker_compose_version: packaging.version.Version
     _file: str = None
     _project_name: str = None
     _project_directory: str = None
 
     def __init__(self,
-                 file=None,
-                 project_name=None,
-                 project_directory=None):
+                 file: str = None,
+                 project_name: str = None,
+                 project_directory: str = None):
         """Initializes an instance of DockerComposeLibrary to use a given Compose file and project name.
 
         `file` Path to compose file. By default, tries to use 'docker-compose.yml'
@@ -44,14 +45,14 @@ class DockerComposeLibrary:
 
         `project_name` Specify an alternate project name (default: test suite name).
         """
-        self._docker_compose_version = self._get_docker_compose_version()
+        self._find_docker_compose()
+        logger.info(f'[Docker Compose Library] Using Docker Compose v${self._docker_compose_version}')
 
         if file is not None:
             self._file = file
         else:
-            suite_source = BuiltIn().get_variable_value('${SUITE SOURCE}')
-            suite_directory = os.path.dirname(suite_source)
-            self._file = os.path.join(suite_directory, 'docker-compose.yml')
+            # by default, use docker-compose.yml located in the suite directory
+            self._file = 'docker-compose.yml'
 
         if project_name is not None:
             self._project_name = project_name
@@ -61,9 +62,21 @@ class DockerComposeLibrary:
         if project_directory is not None:
             self._project_directory = project_directory
         else:
-            self._project_directory = os.path.dirname(self._file)
+            # by default, use suite directory as project directory
+            suite_source = BuiltIn().get_variable_value('${SUITE SOURCE}')
+            self._project_directory = os.path.dirname(suite_source)
 
-        logger.info(f'Docker Compose project "{self._project_name}" initialized using configuration file: {self._file}')
+        # if file path is not absolute, it is considered to be relative to a suite directory
+        if not os.path.isabs(self._file):
+            suite_source = BuiltIn().get_variable_value('${SUITE SOURCE}')
+            self._file = os.path.join(os.path.dirname(suite_source), self._file)
+
+        logger.info(f'[Docker Compose Library] Project "{self._project_name}"'
+                    f' initialized using configuration file: {self._file}')
+
+    def docker_compose_version(self) -> str:
+        """Returns Docker Compose version."""
+        return self._docker_compose_version.base_version
 
     # pylint: disable=R0912, R0913, C0103
     def docker_compose_pull(self,
@@ -107,7 +120,7 @@ class DockerComposeLibrary:
                                     encoding=sys.getdefaultencoding(),
                                     text=True)
         except subprocess.CalledProcessError as e:
-            raise AssertionError(f'Failed to pull image(s): {e.output.rstrip()}') from e
+            raise AssertionError(f'[Docker Compose Pull] Failed to pull image(s): {e.output.rstrip()}') from e
 
     # pylint: disable=R0912, R0913, C0103
     def docker_compose_build(self,
@@ -182,7 +195,7 @@ class DockerComposeLibrary:
                                     encoding=sys.getdefaultencoding(),
                                     text=True)
         except subprocess.CalledProcessError as e:
-            raise AssertionError(f'Failed to build image(s): {e.output.rstrip()}') from e
+            raise AssertionError(f'[Docker Compose Build] Failed to build image(s): {e.output.rstrip()}') from e
 
     # pylint: disable=R0912, R0913, C0103
     def docker_compose_up(self,
@@ -196,6 +209,7 @@ class DockerComposeLibrary:
                           build: bool = False,
                           renew_anon_volumes: bool = True,
                           remove_orphans: bool = True,
+                          wait: bool = None,
                           service_names: List[str] = None) -> None:
         """Builds, (re)creates, starts, and attaches to containers for a service.
         All parameters are forwarded to `docker-compose`.
@@ -222,6 +236,8 @@ class DockerComposeLibrary:
         `remove_orphans` Remove containers for services not defined
         in the Compose file (default: True).
 
+        `wait` Wait for services to be running|healthy (default: True).
+
         `service_names` A list of service names to be started.
         All services are started by default.
 
@@ -244,12 +260,12 @@ class DockerComposeLibrary:
         if force_recreate:
             cmd.append('--force-recreate')
 
-        if self._docker_compose_version >= packaging.version.parse('1.19.0'):
-            if always_recreate_deps is None or always_recreate_deps is True:
-                cmd.append('--always-recreate-deps')
-        elif always_recreate_deps is not None:
-            logger.warn('Docker Compose Up: --always-recreate-deps option'
-                        f' is not supported for docker-compose version {self._docker_compose_version}')
+        if self._docker_compose_version < packaging.version.Version('1.19.0') and always_recreate_deps:
+            logger.warn('[Docker Compose Up] option --always-recreate-deps'
+                        f' is only supported since Docker Compose version v1.19.0'
+                        f' (using Docker Compose v{self._docker_compose_version})')
+        elif always_recreate_deps or always_recreate_deps is None:
+            cmd.append('--always-recreate-deps')
 
         if no_recreate:
             cmd.append('--no-recreate')
@@ -263,16 +279,23 @@ class DockerComposeLibrary:
         if build:
             cmd.append('--build')
 
-        if self._docker_compose_version >= packaging.version.parse('1.19.0'):
-            if renew_anon_volumes is None or renew_anon_volumes is True:
-                cmd.append('--renew-anon-volumes')
-        elif always_recreate_deps is not None:
-            logger.warn('Docker Compose Up: --renew-anon-volumes option'
-                        f' is not supported for docker-compose version {self._docker_compose_version}')
+        if self._docker_compose_version < packaging.version.Version('1.19.0') and renew_anon_volumes:
+            logger.warn('[Docker Compose Up] option --renew-anon-volumes'
+                        f' is only supported since Docker Compose version v1.19.0'
+                        f' (using Docker Compose v{self._docker_compose_version})')
+        elif renew_anon_volumes or renew_anon_volumes is None:
+            cmd.append('--renew-anon-volumes')
 
         if remove_orphans:
             cmd.append('--remove-orphans')
 
+        if self._docker_compose_version < packaging.version.Version('2.0.0') and wait:
+            logger.warn('[Docker Compose Up] option --wait'
+                        f' is only supported since Docker Compose version v2.0.0'
+                        f' (using Docker Compose v{self._docker_compose_version})')
+        elif wait or wait is None:
+            cmd.append('--wait')
+
         if service_names is not None:
             cmd.extend(service_names)
 
@@ -284,7 +307,7 @@ class DockerComposeLibrary:
                                     encoding=sys.getdefaultencoding(),
                                     text=True)
         except subprocess.CalledProcessError as e:
-            raise AssertionError(f'Failed to start services: {e.output.rstrip()}') from e
+            raise AssertionError(f'[Docker Compose Up] Failed to start services: {e.output.rstrip()}') from e
 
     def docker_compose_down(self,
                             timeout: str = None,
@@ -323,14 +346,13 @@ class DockerComposeLibrary:
         cmd: [str] = self._prepare_base_cmd()
         cmd.append('down')
 
-        if self._docker_compose_version >= packaging.version.parse('1.18.0'):
-            if timeout is None:
-                timeout = '10 seconds'
-            cmd.append('--timeout')
-            cmd.append(str(int(convert_time(timeout))))
+        if self._docker_compose_version < packaging.version.Version('1.18.0') and timeout is not None:
+            logger.warn('[Docker Compose Down] option --timeout'
+                        f' is only supported since Docker Compose version v1.18.0'
+                        f' (using Docker Compose v{self._docker_compose_version})')
         elif timeout is not None:
-            logger.warn('Docker Compose Down: --timeout option'
-                        f' is not supported for docker-compose version {self._docker_compose_version}')
+            cmd.append('--timeout')
+            cmd.append(str(int(convert_time(timeout or '10 seconds'))))
 
         if rmi is not None:
             cmd.append('--rmi')
@@ -350,13 +372,252 @@ class DockerComposeLibrary:
                                     encoding=sys.getdefaultencoding(),
                                     text=True)
         except subprocess.CalledProcessError as e:
-            raise AssertionError(f'Failed to shutdown services: {e.output.rstrip()}') from e
+            raise AssertionError(f'[Docker Compose Down] Failed to shutdown services: {e.output.rstrip()}') from e
+
+    def docker_compose_start(self,
+                             service_names: List[str] = None) -> None:
+        """Start services.
+
+        `timeout` Specify stop timeout in seconds (default: 10).
+
+        `service_names` A list of service names to be started.
+
+
+        = Examples =
+
+        Start All Services
+        | Docker Compose Start |
+
+        Start Certain Services
+        | @{service_names} = | Create List |
+        | ... | services1 |
+        | ... | services2 |
+        | Docker Compose Start | service_names=${service_names} |
+        """
+
+        cmd: [str] = self._prepare_base_cmd()
+        cmd.append('start')
+
+        if service_names is not None:
+            cmd.extend(service_names)
+
+        try:
+            subprocess.check_output(cmd,
+                                    cwd=self._project_directory,
+                                    stdin=subprocess.DEVNULL,
+                                    stderr=subprocess.STDOUT,
+                                    encoding=sys.getdefaultencoding(),
+                                    text=True)
+        except subprocess.CalledProcessError as e:
+            raise AssertionError(f'[Docker Compose Start] Failed to start services: {e.output.rstrip()}') from e
+
+    def docker_compose_stop(self,
+                            timeout: str = '10 seconds',
+                            service_names: List[str] = None) -> None:
+        """Stop services.
+
+        `timeout` Specify stop timeout in seconds (default: 10).
+
+        `service_names` A list of service names to be stopped.
+
+
+        = Examples =
+
+        Stop All Services
+        | Docker Compose Stop |
+
+        Stop Certain Services
+        | @{service_names} = | Create List |
+        | ... | services1 |
+        | ... | services2 |
+        | Docker Compose Stop | service_names=${service_names} |
+        """
+
+        cmd: [str] = self._prepare_base_cmd()
+        cmd.append('stop')
+
+        if timeout is not None:
+            cmd.append('--timeout')
+            cmd.append(str(int(convert_time(timeout or '10 seconds'))))
+
+        if service_names is not None:
+            cmd.extend(service_names)
+
+        try:
+            subprocess.check_output(cmd,
+                                    cwd=self._project_directory,
+                                    stdin=subprocess.DEVNULL,
+                                    stderr=subprocess.STDOUT,
+                                    encoding=sys.getdefaultencoding(),
+                                    text=True)
+        except subprocess.CalledProcessError as e:
+            raise AssertionError(f'[Docker Compose Stop] Failed to stop services: {e.output.rstrip()}') from e
+
+    def docker_compose_restart(self,
+                               timeout: str = '10 seconds',
+                               service_names: List[str] = None) -> None:
+        """Restart services.
+
+        `timeout` Specify stop timeout in seconds (default: 10).
+
+        `service_names` A list of service names to be restarted.
+
+
+        = Examples =
+
+        Restart All Services
+        | Docker Compose Restart |
+
+        Restart Certain Services
+        | @{service_names} = | Create List |
+        | ... | services1 |
+        | ... | services2 |
+        | Docker Compose Restart | service_names=${service_names} |
+        """
+
+        cmd: [str] = self._prepare_base_cmd()
+        cmd.append('restart')
+
+        if timeout is not None:
+            cmd.append('--timeout')
+            cmd.append(str(int(convert_time(timeout or '10 seconds'))))
+
+        if service_names is not None:
+            cmd.extend(service_names)
+
+        try:
+            subprocess.check_output(cmd,
+                                    cwd=self._project_directory,
+                                    stdin=subprocess.DEVNULL,
+                                    stderr=subprocess.STDOUT,
+                                    encoding=sys.getdefaultencoding(),
+                                    text=True)
+        except subprocess.CalledProcessError as e:
+            raise AssertionError(f'[Docker Compose Restart] Failed to restart services: {e.output.rstrip()}') from e
+
+    def docker_compose_kill(self,
+                            remove_orphans: bool = False,
+                            signal: str = None,
+                            service_names: List[str] = None) -> None:
+        """Force stop service containers.
+
+        `signal` SIGNAL to send to the container (default "SIGKILL").
+
+        `remove_orphans` Remove containers for services not defined in the Compose file.
+
+
+        = Examples =
+
+        Kill All Services
+        | Docker Compose Kill |
+
+        Kill Certain Services
+        | @{service_names} = | Create List |
+        | ... | services1 |
+        | ... | services2 |
+        | Docker Compose Kill | service_names=${service_names} |
+        """
+
+        cmd: [str] = self._prepare_base_cmd()
+        cmd.append('kill')
+
+        if remove_orphans:
+            cmd.append('--remove-orphans')
+
+        if signal is not None:
+            cmd.append('--signal')
+            cmd.append(signal)
+
+        if service_names is not None:
+            cmd.extend(service_names)
+
+        try:
+            output = subprocess.check_output(cmd,
+                                             cwd=self._project_directory,
+                                             stdin=subprocess.DEVNULL,
+                                             stderr=subprocess.STDOUT,
+                                             encoding=sys.getdefaultencoding(),
+                                             text=True)
+            if output == 'no container to kill':
+                raise AssertionError(f'[Docker Compose Kill] No container(s) to kill for service: ${service_names}')
+        except subprocess.CalledProcessError as e:
+            raise AssertionError(f'[Docker Compose Kill] Failed to kill services: {e.output.rstrip()}') from e
+
+    def docker_compose_pause(self,
+                             service_names: List[str] = None) -> None:
+        """Pause services.
+
+        `service_names` A list of service names to be paused.
+
+
+        = Examples =
+
+        Pause All Services
+        | Docker Compose Pause |
+
+        Pause Certain Services
+        | @{service_names} = | Create List |
+        | ... | services1 |
+        | ... | services2 |
+        | Docker Compose Pause | service_names=${service_names} |
+        """
+
+        cmd: [str] = self._prepare_base_cmd()
+        cmd.append('pause')
+
+        if service_names is not None:
+            cmd.extend(service_names)
+
+        try:
+            subprocess.check_output(cmd,
+                                    cwd=self._project_directory,
+                                    stdin=subprocess.DEVNULL,
+                                    stderr=subprocess.STDOUT,
+                                    encoding=sys.getdefaultencoding(),
+                                    text=True)
+        except subprocess.CalledProcessError as e:
+            raise AssertionError(f'[Docker Compose Pause] Failed to pause services: {e.output.rstrip()}') from e
+
+    def docker_compose_unpause(self,
+                               service_names: List[str] = None) -> None:
+        """Unpause services.
+
+        `service_names` A list of service names to be unpaused.
+
+
+        = Examples =
+
+        Unpause All Services
+        | Docker Compose Unpause |
+
+        Unpause Certain Services
+        | @{service_names} = | Create List |
+        | ... | services1 |
+        | ... | services2 |
+        | Docker Compose Unpause | service_names=${service_names} |
+        """
+
+        cmd: [str] = self._prepare_base_cmd()
+        cmd.append('unpause')
+
+        if service_names is not None:
+            cmd.extend(service_names)
+
+        try:
+            subprocess.check_output(cmd,
+                                    cwd=self._project_directory,
+                                    stdin=subprocess.DEVNULL,
+                                    stderr=subprocess.STDOUT,
+                                    encoding=sys.getdefaultencoding(),
+                                    text=True)
+        except subprocess.CalledProcessError as e:
+            raise AssertionError(f'[Docker Compose Unpause] Failed to unpause services: {e.output.rstrip()}') from e
 
     def docker_compose_logs(self,
                             write_to: str = None,
                             prefix: bool = True,
                             timestamps: bool = True,
-                            service_names: List[str] = None) -> None:
+                            service_names: List[str] = None) -> str:
         """Grabs or saves the output from containers.
 
         `write_to` Name of the log file to use. Can be an absolute or
@@ -413,7 +674,7 @@ class DockerComposeLibrary:
                                      encoding=sys.getdefaultencoding(),
                                      text=True)
         except subprocess.CalledProcessError as e:
-            raise AssertionError(f'Failed to get logs: {e.stderr}') from e
+            raise AssertionError(f'[Docker Compose Logs] Failed to get service logs: {e.stderr}') from e
         finally:
             close_output_file()
 
@@ -424,7 +685,7 @@ class DockerComposeLibrary:
     def get_exposed_service(self,
                             service_name: str,
                             port: int,
-                            protocol: str = None):
+                            protocol: str = None) -> ExposedServiceInfo:
         """Retrieves host address and port number for a port exposed by service.
 
         `service_name` Service name from Compose file.
@@ -468,22 +729,52 @@ class DockerComposeLibrary:
                                              encoding=sys.getdefaultencoding(),
                                              text=True)
         except subprocess.CalledProcessError as e:
-            raise AssertionError(e.output.rstrip()) from e
+            raise AssertionError(
+                f'[Get Exposed Service] Failed to query exposed ports for service {service_name}: {e.stderr}') from e
+
+        # Docker Compose V1 returns empty string when querying port that is not exposed.
+        # Docker Compose V2 returns string ':0' in this case.
         result = output.rstrip().split(':')
-        if len(result) == 1:
-            raise AssertionError(f'Port {port} is not exposed for service {service_name}')
+        if len(result) != 2 or (result[0] == '' and result[1] == '0'):
+            raise AssertionError(f'[Get Exposed Service] Port {port} is not exposed for service {service_name}')
+
         return result
 
     def _prepare_base_cmd(self) -> [str]:
         """Helper function to create a 'docker-compose' command with project name and file arguments."""
-        return [
-            'docker-compose',
-            '--project-name', self._project_name,
-            '--file', self._file,
-        ]
+        cmd = self._docker_compose_cmd.copy()
 
-    def _get_docker_compose_version(self) -> packaging.version.Version:
-        """Helper function to retrieve docker-compose version"""
+        cmd.append('--project-name')
+        cmd.append(self._project_name)
+
+        cmd.append('--file')
+        cmd.append(self._file)
+
+        return cmd
+
+    def _find_docker_compose(self) -> [str]:
+        """Helper function to find and set Docker Compose executable and version"""
+        # noinspection PyBroadException
+        try:
+            cmd = [
+                'docker',
+                'compose',
+                'version'
+            ]
+            version_string = subprocess.check_output(cmd,
+                                                     cwd=self._project_directory,
+                                                     stdin=subprocess.DEVNULL,
+                                                     stderr=subprocess.STDOUT,
+                                                     encoding=sys.getdefaultencoding(),
+                                                     text=True).rstrip()
+
+            self._docker_compose_cmd = ['docker', 'compose']
+            self._docker_compose_version = self._parse_docker_compose_version(version_string)
+            return
+        except subprocess.CalledProcessError:
+            pass
+
+        # Fall back to Docker Compose V1.
         try:
             cmd = [
                 'docker-compose',
@@ -495,10 +786,19 @@ class DockerComposeLibrary:
                                                      stderr=subprocess.STDOUT,
                                                      encoding=sys.getdefaultencoding(),
                                                      text=True).rstrip()
-            version_string = re.findall(r'(?:(\d+\.(?:\d+\.)*\d+))', version_string)[0]
-            return packaging.version.parse(version_string)
-        except Exception as e:
-            raise AssertionError('Could not determine docker-compose version') from e
+            self._docker_compose_cmd = ['docker-compose']
+            self._docker_compose_version = self._parse_docker_compose_version(version_string)
+        except subprocess.CalledProcessError as e:
+            raise AssertionError('[Docker Compose Library] Unable to find Docker Compose on path') from e
+
+    @staticmethod
+    def _parse_docker_compose_version(version_string: str) -> packaging.version.Version:
+        """Helper function to parse Docker Compose version string"""
+        try:
+            version_string = re.findall(r'(\d+\.(?:\d+\.)*\d+)', version_string)[0]
+            return packaging.version.Version(version_string)
+        except packaging.version.InvalidVersion as e:
+            raise AssertionError('[Docker Compose Library] Could not parse docker-compose version') from e
 
     @staticmethod
     def _is_inside_container() -> bool:
@@ -530,7 +830,7 @@ class DockerComposeLibrary:
                 if '/docker/containers/' not in line:
                     continue
                 return line.split('/docker/containers/')[-1].split('/')[0]
-            raise AssertionError('Failed to obtain container id')
+            raise AssertionError('[Docker Compose Library] Failed to obtain container id')
 
     @staticmethod
     def _do_nothing(*args):
